# unitorch.cli.models.pegasus

## PegasusProcessor

!!! tip
    **`core/process/pegasus`** is the section for configuration of PegasusProcessor.

::: unitorch.cli.models.pegasus.PegasusProcessor

## PegasusForGeneration

!!! tip
    **`core/model/generation/pegasus`** is the section for configuration of PegasusForGeneration.

::: unitorch.cli.models.pegasus.PegasusForGeneration
